@@ -142,7 +142,6 @@ $_gmsg['l_allowdirectaccess'] = '允许直接访问';
 $_gmsg['l_allowedRobotHits'] = '允许的机器人命中';
 $_gmsg['l_allowedhosts'] = '允许的域名';
 $_gmsg['l_allowoverride'] = '允许覆盖';
-$_gmsg['l_allowquic'] = '允许QUIC';
 $_gmsg['l_allowsetuid'] = '允许设置UID';
 $_gmsg['l_allowsymbollink'] = '跟随符号链接';
 $_gmsg['l_apachebinpath'] = 'Apache执行程序路径';
@@ -260,11 +259,10 @@ $_gmsg['l_enablehotlinkctrl'] = '启用盗链防护';
 $_gmsg['l_enableipgeo'] = '启用IP地理定位';
 $_gmsg['l_enablelve'] = 'Cloud Linux';
 $_gmsg['l_enableprivatecache'] = '启用私有缓存';
-$_gmsg['l_enablequic'] = '启用QUIC';
+$_gmsg['l_enablequic'] = '启用HTTP3/QUIC';
 $_gmsg['l_enablerailshosting'] = '启用共享主机';
 $_gmsg['l_enablerewrite'] = '启用重写';
 $_gmsg['l_enablescript'] = '启用脚本/外部应用程序';
-$_gmsg['l_enablespdy'] = '启用SPDY/HTTP2';
 $_gmsg['l_enablestapling'] = '启用OCSP Stapling';
 $_gmsg['l_enablestderrlog'] = '启用标准错误日志（stderr）';
 $_gmsg['l_env'] = '环境变量';
@@ -421,7 +419,7 @@ $_gmsg['l_process'] = '进程';
 $_gmsg['l_prochardlimit'] = '进程硬限制';
 $_gmsg['l_procsoftlimit'] = '进程软限制';
 $_gmsg['l_protocolver'] = '协议版本';
-$_gmsg['l_quic'] = 'QUIC';
+$_gmsg['l_quic'] = 'HTTP3/QUIC';
 $_gmsg['l_quiccfcw'] = '连接流量控制窗口';
 $_gmsg['l_quichandshaketimeout'] = '握手超时时间（秒）';
 $_gmsg['l_quicidletimeout'] = '空闲超时时间（秒）';
@@ -430,7 +428,7 @@ $_gmsg['l_quicmaxsfcw'] = '最大流量窗口值设置';
 $_gmsg['l_quicmaxstreams'] = '每个连接的最大并发数';
 $_gmsg['l_quicsfcw'] = '连接流量窗口值';
 $_gmsg['l_quicshmdir'] = 'QUIC SHM 目录';
-$_gmsg['l_quicversions'] = 'QUIC 版本';
+$_gmsg['l_quicversions'] = 'HTTP3/QUIC 版本';
 $_gmsg['l_railsapplimit'] = '单账号最大应用程序数量';
 $_gmsg['l_railshosting'] = 'Rack/Rails共享主机';
 $_gmsg['l_railssettings'] = 'App Server设置';
